@@ -7,11 +7,6 @@ void BinomLogitMixed(int *Y, double **X, double ***Z, int *grp, double *beta,
 		     double **T0, double **tune_fixed, double *tune_random, int n_gen,
 		     int *acc_fixed, int *acc_random);
 
-void bNormalReg(double *Y, double **X, double *beta, double *sig2, 
-		int n_samp, int n_cov, int addprior, int pbeta, 
-		double *beta0, double **A0, int psig2, double s0, 
-		int nu0, int sig2fixed);
-
 void RobitGibbs(int *Y, double **X, double *beta, int n_samp, int n_cov, int prior, double *beta0, double **A0,	int df,	int n_gen);
 
 void endorseoprobitMCMC(int *Y, double **X, double *beta, 
@@ -19,12 +14,16 @@ void endorseoprobitMCMC(int *Y, double **X, double *beta,
 			 int prior, double *beta0, double **A0, int mda, 
 			 int mh, double *prop, int *accept, int n_gen);
  
-void bNormalReg1(double **X, double *beta, 
-		 int n_samp, int n_cov, int prior, 
-		 double *beta0, double **A0, double *tau, 
-		 int df, int n_gen);
+void bNormalReg(double *Y, double **X, double *beta, double *sig2, 
+		int n_samp, int n_cov, int addprior, int pbeta, 
+		double *beta0, double **A0, int psig2, double s0, 
+		int nu0, int sig2fixed, int conjugate);
 
-void bNormalReg2(double **D, double *beta, double *sig2, 
-		 int n_samp, int n_cov, int addprior, int pbeta, 
-		 double *beta0, double **A0, int psig2, double s0, 
-		 int nu0, int sig2fixed);
+void bNormalReg1(double **D, double *beta, double *sig2, 
+		int n_samp, int n_cov, int addprior, int pbeta, 
+		double *beta0, double **A0, int psig2, double s0, 
+		int nu0, int sig2fixed, int conjugate);
+
+void bprobitGibbs(int *Y, double **X, double *beta,
+		  int n_samp, int n_cov, int prior, double *beta0,
+		  double **A0, int mda,	int n_gen);
